# applyllm: Training and Serving LLMs and SLMs

This repository contains the code for the [applyllm](https://pypi.org/project/applyllm/) python package, which supports loading and training open‑source LLM models such as LLaMA 2, Mixtral 8x7B, and etc. on CUDA and MPS.

## Install the package
```shell
pip install applyllm
```

